<?php
if (!class_exists("WP_List_Table")) {
    require_once( ABSPATH . "wp-admin/includes/class-wp-list-table.php" );
}

class wpdUserFollowsList extends WP_List_Table {

    private $db;
    private $user;

    public function __construct($db) {
        $this->db = $db;
        $this->user = wp_get_current_user();
        parent::__construct([
            "singular" => "wpds_user_follow",
            "plural" => "wpds_user_follows",
            "ajax" => false
        ]);
    }

    public function get_columns() {
        $columns = [
            "cb" => "<input type='checkbox' />",
			"user_name" => __("Followed User Name", "wpdiscuz_sbm"),
            "actions" => __("Actions", "wpdiscuz_sbm"),
			"follow_date" => __("Date", "wpdiscuz_sbm"),
        ];
        return $columns;
    }

    public function column_cb($item) {
        return sprintf(
                '<input type="checkbox" name="%1$s[]" value="%2$s" />',
                /* $1%s */ $this->_args["singular"], //Let's simply repurpose the table's singular label ("movie")
                /* $2%s */ $item["id"]                //The value of the checkbox should be the record's id
        );
    }

    public function column_user_name($item) {
        $htmlID = "bell-" . $item["id"];
        if ($item["confirm"] == 1) {
            $html = "<i id='{$htmlID}' class='fas fa-bell wpds-confirmed' aria-hidden='true'  title='" . __("Confirmed", "wpdiscuz_sbm") . "'></i>";
        } else {
            $html = "<i id='{$htmlID}' class='fas fa-bell-slash wpds-awaiting-confirmation' aria-hidden='true' title='" . __("Awaiting confirmation", "wpdiscuz_sbm") . "'></i>";
        }
        return $html . $item["user_name"];
    }

    public function column_actions($item) {
        $id = $item["id"];
        $actionUrl = wp_nonce_url(admin_url("admin-post.php?action=wpdiscuz_sbm_follow_action&id=" . $id), "wpdiscuz-sbm", "wpdiscuz-sbm-nonce");
        if ($item["confirm"] == 1) {
            $html = " <a href='" . $actionUrl . "&action-name=cancel'><i class='fas fa-bell-slash unconfirm wpds-awaiting-confirmation button' aria-hidden='true'  title='" . __("Cancel confirmation", "wpdiscuz_sbm") . "'></i></a>";
        } else {
            $html = " <a href='" . $actionUrl . "&action-name=confirm'><i class='fas fa-bell confirm wpds-confirmed button' aria-hidden='true' title='" . __("Set as confirmed", "wpdiscuz_sbm") . "'></i></a>";
        }
        $html .= " <a href='" . $actionUrl . "&action-name=delete'><i class='fas fa-trash-alt delete wpds-delete button' aria-hidden='true'  title='" . __("Unsubscribe", "wpdiscuz_sbm") . "'></i></a>";
        return $html;
    }

    public function column_follow_date($item) {
        return date_i18n(get_option("date_format"), strtotime($item["follow_date"]));
    }

    public function column_default($item, $column_name) {
        return $item[$column_name];
    }

    public function extra_tablenav($which) {
        if ($which == "top") {
            $dateArray = $this->db->getAllFollowsDate($this->user->ID);
            $status = filter_input(INPUT_GET, "wpds_subscribe_confirm", FILTER_SANITIZE_NUMBER_INT);
            $type = filter_input(INPUT_GET, "wpds_subscribe_type", FILTER_SANITIZE_STRING);
            $_date = filter_input(INPUT_GET, "wpds_subscribe_date", FILTER_SANITIZE_STRING);
            ?>
            <select name="wpds_follow_confirm">
                <option value="" <?php selected($status, null); ?>><?php _e("All Status", "wpdiscuz_sbm"); ?></option>
                <option value="1" <?php selected($status, 1); ?>><?php _e("Confirmed", "wpdiscuz_sbm"); ?></option>
                <option value="0" <?php selected($status, 0); ?>><?php _e("Awaiting confirmation", "wpdiscuz_sbm"); ?></option>
            </select>
            <select name="wpds_follow_date">
                <option value=""><?php _e("All Dates", "wpdiscuz_sbm") ?></option>
                <?php
                foreach ($dateArray as $date) {
                    ?>
                    <option value="<?php echo $date; ?>" <?php selected($_date, $date); ?>><?php echo date_i18n("F , Y", strtotime($date . "-01")); ?></option>
                    <?php
                }
                ?>
            </select>
            <input  class="button" name="filter_action" value="<?php _e("Filter", "wpdiscuz_sbm"); ?>" type="submit">
            <a  class="reset-button" href="<?php echo admin_url("users.php?page=" . wpdSubscribeManager::WPDF_USER_SLUG); ?>"><?php _e("Reset Filters", "wpdiscuz_sbm"); ?></a>
            <?php
        }
    }

    public function get_sortable_columns() {
        return [
			"user_name" => ["user_name", false],
			"follow_date" => ["follow_date", false],
		];
    }

    public function get_bulk_actions() {
        return [
			"confirm" => __("Set as confirmed", "wpdiscuz_sbm"),
			"cancel" => __("Cancel confirmation", "wpdiscuz_sbm"),
			"delete" => __("Unfollow ", "wpdiscuz_sbm")
		];
    }

    public function process_bulk_action() {
        $subscriptions = filter_input(INPUT_GET, "wpds_user_follow", FILTER_SANITIZE_NUMBER_INT, FILTER_REQUIRE_ARRAY);
        $nonce = filter_input(INPUT_GET, "_wpnonce", FILTER_SANITIZE_STRING);
        if ($this->user->ID && wp_verify_nonce($nonce, "bulk-" . $this->_args["plural"]) && $subscriptions) {
            if ("confirm" === $this->current_action()) {
                $this->db->bulkChangeFollowsConfirmationStatus($subscriptions, 1, $this->user->ID);
            } else if ("cancel" === $this->current_action()) {
                $this->db->bulkChangeFollowsConfirmationStatus($subscriptions, 0, $this->user->ID);
            } else if ("delete" === $this->current_action()) {
                $this->db->bulkDeleteFollow($subscriptions, $this->user->ID);
            }
        }
    }

    public function prepare_items() {
        $per_page = $this->get_items_per_page("follows_per_page");
        $columns = $this->get_columns();
        $hidden = [];
        $sortable = $this->get_sortable_columns();
        $this->_column_headers = [$columns, $hidden, $sortable];

        $this->process_bulk_action();
        $total_items = $this->db->followsCount($this->user->ID);
        $data = $this->_getFollows($per_page, $total_items);
        $this->items = $data;

        $this->set_pagination_args([
            "total_items" => $total_items,
            "per_page" => $per_page,
            "total_pages" => ceil($total_items / $per_page)
        ]);
    }

    private function _getFollows($per_page, $total_items) {
        $data = [];
        if ($this->user->ID) {
            $current_page = $this->get_pagenum();
            $data = $this->db->getFollows($per_page, $current_page, $this->user->ID);
            if (!$data && $total_items) {
                $data = $this->db->getSubscriptions($per_page, $current_page - 1);
            }
        }
        return $data;
    }

}
